@@ -1045,3 +1045,33 @@ def test_json(cnxn):
     result = cnxn.fetchval("select j from t1")
 
     assert value == result
+
+
+def test_empty_json(cnxn):
+    value = {}
+    cnxn.execute("create table t1(j json)")
+    cnxn.execute("insert into t1 values($1)", value)
+    result = cnxn.fetchval("select j from t1")
+    assert value == result
+
+def test_jsonb(cnxn):
+
+    value = {
+        'one': 1,
+        'a': [1, 2, 3],
+        '2': 'two'
+    }
+
+    cnxn.execute("create table t1(j jsonb)")
+    cnxn.execute("insert into t1 values($1)", value)
+    result = cnxn.fetchval("select j from t1")
+
+    assert value == result
+
+
+def test_empty_jsonb(cnxn):
+    value = {}
+    cnxn.execute("create table t1(j jsonb)")
+    cnxn.execute("insert into t1 values($1)", value)
+    result = cnxn.fetchval("select j from t1")
+    assert value == result
